@@ -32,11 +32,12 @@ def get_mnemonic(direction, prefix, p, i, f):
         key = '%s CSI %s%s%s' % (direction, p, i, f)
         if key in _DB:
             return _DB[key] 
-        length = len()
+        length = len(params)
 
-    key = '%s CSI %s%s;*%s%s' % (direction, prefix, params[0], i, f)
-    if key in _DB:
-        return _DB[key] 
+    if length > 0:
+        key = '%s CSI %s%s;*%s%s' % (direction, prefix, params[0], i, f)
+        if key in _DB:
+            return _DB[key] 
 
     key = '%s CSI %s[%d]%s%s' % (direction, prefix, length, i, f)
     if key in _DB:
