@@ -18,12 +18,37 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ***** END LICENSE BLOCK *****
 
+'''
+Reference:
+
+- Xterm Control Sequences
+  http://invisible-island.net/xterm/ctlseqs/ctlseqs.html
+
+- TeraTerm / Supported Control Functions
+  http://ttssh2.sourceforge.jp/manual/en/about/ctrlseq.html
+
+'''
+
 _SEQDB = {
-    '> ESC P<ST>'    : 'DCS',
-    '> ESC ]<ST>'    : 'OSC',
-    '> ESC ^<ST>'    : 'PM',
-    '> ESC _<ST>'    : 'APC',
-    '> ESC X<ST>'    : 'SOS',
+    '> ESC P<ST>'    : 'DCS / device control string',
+    '> ESC ]<ST>'    : 'OSC / operating system command',
+    '> ESC ]0<ST>'   : 'OSC 0 / set icon name and window title',
+    '> ESC ]1<ST>'   : 'OSC 1 / set icon name',
+    '> ESC ]2<ST>'   : 'OSC 2 / set window title',
+    '> ESC ]4<ST>'   : 'OSC 4 / get or set color palette',
+    '> ESC ]9<ST>'   : 'OSC 9 / Growl integration (iTerm2)',
+    '> ESC ]10<ST>'  : 'OSC 10 / get or set foreground color',
+    '> ESC ]11<ST>'  : 'OSC 11 / get or set background color',
+    '> ESC ]12<ST>'  : 'OSC 12 / get or set cursor color',
+    '> ESC ]13<ST>'  : 'OSC 13 / get or set mouse foreground color',
+    '> ESC ]14<ST>'  : 'OSC 13 / get or set mouse background color',
+    '> ESC ]51<ST>'  : 'OSC 51 / reserved for Emacs',
+    '> ESC ]52<ST>'  : 'OSC 52 - PASTE64 / base64 clipboard read/write operation (xterm)',
+    '> ESC ^<ST>'    : 'PM / private message',
+    '> ESC _<ST>'    : 'APC / application program command',
+    '> ESC V'        : 'SPA / start of guarded area',
+    '> ESC W'        : 'EPA / end of guarded area',
+    '> ESC X<ST>'    : 'SOS / start of string',
     '< CSI [0]M'     : 'xterm normal mouse reporting, following 3 bytes mean (code, row, col)',
     '< CSI M'        : 'URXVT (1015) mouse reporting (code, row, col)',
     '< CSI [3]M'     : 'URXVT (1015) mouse reporting (code, row, col)',
@@ -37,31 +62,52 @@ _SEQDB = {
     '< CSI 0n'       : 'DSR-OS(operating status report) response: "good status"',
     '< CSI 3n'       : 'DSR-OS(operating status report) response: "it has a malfunction"',
     '< CSI ?c'       : 'DA1 Response',
+    '< CSI ?1;2c'    : 'DA1 Response: VT100 with advanced video option',
+    '< CSI ?1;0c'    : 'DA1 Response: VT100 with no options',
     '< CSI >c'       : 'DA2 Response',
-    '< CSI 15~ '     : 'F5 key (xterm)',
-    '< CSI 17~ '     : 'F6 key (xterm)',
-    '< CSI 18~ '     : 'F7 key (xterm)',
-    '< CSI 19~ '     : 'F8 key (xterm)',
-    '< CSI 20~ '     : 'F9 key (xterm)',
-    '< CSI 21~ '     : 'F10 key (xterm)',
-    '< CSI 23~ '     : 'F11 key (xterm)',
-    '< CSI 24~ '     : 'F12 key (xterm)',
-    '> ESC 6'        : 'DECBI',
-    '> ESC 7'        : 'DECSC',
-    '> ESC 8'        : 'DECRC',
-    '> ESC 9'        : 'DECFI',
-    '> ESC ='        : 'DECKPAM',
-    '> ESC >'        : 'DECKPNM',
+    '< CSI >0;*c'    : 'DA2 Response: VT100',
+    '< CSI >1;*c'    : 'DA2 Response: VT220',
+    '< CSI >2;*c'    : 'DA2 Response: VT240',
+    '< CSI >18;*c'   : 'DA2 Response: VT330',
+    '< CSI >19;*c'   : 'DA2 Response: VT340',
+    '< CSI >19;*c'   : 'DA2 Response: VT340',
+    '< CSI >24;*c'   : 'DA2 Response: VT320',
+    '< CSI >41;*c'   : 'DA2 Response: VT420',
+    '< CSI >61;*c'   : 'DA2 Response: VT510',
+    '< CSI >64;*c'   : 'DA2 Response: VT520',
+    '< CSI >65;*c'   : 'DA2 Response: VT525',
+    '< CSI 15~'      : 'F5 key (xterm)',
+    '< CSI 17~'      : 'F6 key (xterm)',
+    '< CSI 18~'      : 'F7 key (xterm)',
+    '< CSI 19~'      : 'F8 key (xterm)',
+    '< CSI 20~'      : 'F9 key (xterm)',
+    '< CSI 21~'      : 'F10 key (xterm)',
+    '< CSI 23~'      : 'F11 key (xterm)',
+    '< CSI 24~'      : 'F12 key (xterm)',
+    '> ESC D'        : 'IND / moves the cursor down one line in the same column',
+    '> ESC E'        : 'NEL / moves the cursor to the first position on the next line',
+    '> ESC H'        : 'HTS / sets a horizontal tab stop at the column where the cursor is. ',
+    '> ESC M'        : 'HTS / moves the cursor up one line in the same column',
+    '> ESC N'        : 'SS2 / temporarily maps the G2 character set into GL or GR, for the next graphic character',
+    '> ESC O'        : 'SS3 / temporarily maps the G3 character set into GL or GR, for the next graphic character',
+    '> ESC \\'       : 'ST / String terminator. Ends a DCS, SOS, OSC, PM and APC sequence',
+    '> ESC 6'        : 'DECBI / backward index',
+    '> ESC 7'        : 'DECSC / save cursor',
+    '> ESC 8'        : 'DECRC / restore cursor',
+    '> ESC 9'        : 'DECFI / forward index',
+    '> ESC ='        : 'DECKPAM / application keypad',
+    '> ESC >'        : 'DECKPNM / normal keypad',
+    '> ESC c'        : 'RIS / full reset',
     '> ESC <SP>F'    : 'S7C1T',
     '> ESC <SP>G'    : 'S8C1T',
     '> ESC <SP>L'    : 'Set ANSI conformance level 1',
     '> ESC <SP>M'    : 'Set ANSI conformance level 2',
     '> ESC <SP>N'    : 'Set ANSI conformance level 3',
-    '> ESC #3'       : 'DECDHLT',
-    '> ESC #4'       : 'DECDHLB',
-    '> ESC #5'       : 'DECSWL',
-    '> ESC #6'       : 'DECDWL',
-    '> ESC #8'       : 'DECALN',
+    '> ESC #3'       : 'DECDHLT / double height line, top half',
+    '> ESC #4'       : 'DECDHLB / double height line, bottom half',
+    '> ESC #5'       : 'DECSWL / single width line',
+    '> ESC #6'       : 'DECDWL / double width line',
+    '> ESC #8'       : 'DECALN / screen alignment pattern',
     '> ESC %@'       : 'Select default character set',
     '> ESC %G'       : 'Select UTF-8 character set',
     '> ESC (0'       : 'designate G0 charset: DEC Special Character and Line Drawing Set',
@@ -191,7 +237,7 @@ _SEQDB = {
     '> CSI [0]a'     : 'HPR 1 / horizontal position relative',
     '> CSI b'        : 'REP / repeat',
     '> CSI c'        : 'DA1 / request primary device attribute',
-    '> CSI > c'      : 'DA2 / request secondary device attribute',
+    '> CSI >c'       : 'DA2 / request secondary device attribute',
     '> CSI d'        : 'VPA / vertical position absolute',
     '> CSI e'        : 'VPR / vertical position relative',
     '> CSI f'        : 'HVP / horizontal and vertical position',
@@ -199,7 +245,7 @@ _SEQDB = {
     '> CSI h'        : 'SM / set mode',
     '> CSI ?h'       : 'DECSET',
     '> CSI ?1h'      : 'DECSET 1 - DECCKM / application cursor keys',
-    '> CSI ?2h'      : 'DECSET 2 - DECANM / designate USASCII for character sets G0-G3 (DECANM), and set VT100 mode',
+    '> CSI ?2h'      : 'DECSET 2 - DECANM / designate USASCII for G0-G3 (DECANM), and set VT100 mode',
     '> CSI ?3h'      : 'DECSET 3 - DECCOLM / 132 column mode',
     '> CSI ?4h'      : 'DECSET 4 - DECSCLM / enable smooth scroll mode',
     '> CSI ?5h'      : 'DECSET 5 - DECSCNM / enable reverse video',
@@ -209,6 +255,7 @@ _SEQDB = {
     '> CSI ?9h'      : 'DECSET 9 / enable X10 compatible mouse mode',
     '> CSI ?10h'     : 'DECSET 10 / show toolbar (rxvt)',
     '> CSI ?12h'     : 'DECSET 12 / blinking cursor (att610)',
+    '> CSI ?12;25h'  : 'DECSET 12;25 / visible and blinking cursor',
     '> CSI ?25h'     : 'DECSET 25 - DECTCEM / show cursor',
     '> CSI ?1000h'   : 'DECSET 1000 / enable xterm normal mouse tracking',
     '> CSI ?1001h'   : 'DECSET 1001 / enable highlight mouse tracking',
@@ -218,7 +265,10 @@ _SEQDB = {
     '> CSI ?1005h'   : 'DECSET 1005 / enable UTF8 mouse mode',
     '> CSI ?1006h'   : 'DECSET 1006 / enable SGR mouse mode',
     '> CSI ?1007h'   : 'DECSET 1007 / enable alternate scroll mode',
+    '> CSI ?1047h'   : 'DECSET 1047 / use alternate screen buffer',
+    '> CSI ?1049h'   : 'DECSET 1049 / save cursor as in DECSC and use alternate screen buffer',
     '> CSI ?2004h'   : 'DECSET 2004 / enable bracketed paste mode',
+    '> CSI ?7700h'   : 'DECSET 7700 / enable ambiguous reporting (mintty)',
     '> CSI i'        : 'MC',
     '> CSI ?i'       : 'MC - DEC Specific',
     '> CSI l'        : 'RM',
@@ -243,15 +293,20 @@ _SEQDB = {
     '> CSI ?1005l'   : 'DECRST 1005 / disable UTF8 mouse mode',
     '> CSI ?1006l'   : 'DECRST 1006 / disable SGR mouse mode',
     '> CSI ?1007l'   : 'DECRST 1007 / disable alternate scroll mode',
+    '> CSI ?1047l'   : 'DECRST 1047 / use normal screen buffer',
+    '> CSI ?1049l'   : 'DECRST 1049 / use normal screen buffer and restore cursor as in DECRC',
     '> CSI ?2004l'   : 'DECRST 2004 / reset bracketed paste mode',
+    '> CSI ?7700l'   : 'DECRST 7700 / disable ambiguous reporting (mintty)',
     '> CSI m'        : 'SGR',
     '> CSI 0m'       : 'SGR 0 / reset',
+    '> CSI 00m'      : 'SGR 0 / reset',
     '> CSI [0]m'     : 'SGR 0 / reset',
     '> CSI 1m'       : 'SGR 1 / bold',
     '> CSI 4m'       : 'SGR 4 / underlined',
     '> CSI 5m'       : 'SGR 5 / blink',
     '> CSI 7m'       : 'SGR 7 / inverse',
     '> CSI 22m'      : 'SGR 22 / normal (neigher bold nor faint)',
+    '> CSI 24m'      : 'SGR 24 / not underlined',
     '> CSI 25m'      : 'SGR 25 / steady (not blinking)',
     '> CSI 27m'      : 'SGR 27 / positive (not inverse)',
     '> CSI 30m'      : 'SGR 30 / set fourground color to black',
@@ -263,6 +318,7 @@ _SEQDB = {
     '> CSI 36m'      : 'SGR 36 / set fourground color to cyan',
     '> CSI 37m'      : 'SGR 37 / set fourground color to white',
     '> CSI 39m'      : 'SGR 39 / set fourground color to default',
+    '> CSI 39;49m'   : 'SGR 39;49 / set fourground and background color to default',
     '> CSI 40m'      : 'SGR 40 / set background color to black',
     '> CSI 41m'      : 'SGR 41 / set background color to red',
     '> CSI 42m'      : 'SGR 42 / set background color to green',
@@ -295,7 +351,7 @@ _SEQDB = {
     '> CSI ?n'       : 'DSR - DEC Specific',
     '> CSI ?6n'      : 'DSR - DECXCPR / requests cursor position report, DEC Specific',
     '> CSI >n'       : 'Disable Special Keyboard Modifier Settings (xterm)',
-    '> CSI r'        : 'DECSTBM',
+    '> CSI r'        : 'DECSTBM / set top and bottom margins',
     '> CSI t'        : 'DECSLPP or Window Manipulation (dtterm)'
 }
 
